summaryrefslogtreecommitdiffstats
path: root/generic/tclHash.c
diff options
context:
space:
mode:
authordavygrvy <davygrvy@pobox.com>2003-12-24 04:18:18 (GMT)
committerdavygrvy <davygrvy@pobox.com>2003-12-24 04:18:18 (GMT)
commit5d224fb11538aa654ba2028f75e5ffa06df2c579 (patch)
treeeff546c6e792fecd4310f81379419c1d68d63c28 /generic/tclHash.c
parentbdb55bff6176c625c664d4ea5a4ec5187839d7a8 (diff)
downloadtcl-5d224fb11538aa654ba2028f75e5ffa06df2c579.zip
tcl-5d224fb11538aa654ba2028f75e5ffa06df2c579.tar.gz
tcl-5d224fb11538aa654ba2028f75e5ffa06df2c579.tar.bz2
All uses of 'panic' (the macro) changed
to 'Tcl_Panic' (the function). The #define of panic in tcl.h clearly states it is deprecated in the comments. [Patch 865264]
Diffstat (limited to 'generic/tclHash.c')
-rw-r--r--generic/tclHash.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/generic/tclHash.c b/generic/tclHash.c
index aeb04f9..3d8fd00 100644
--- a/generic/tclHash.c
+++ b/generic/tclHash.c
@@ -10,7 +10,7 @@
* See the file "license.terms" for information on usage and redistribution
* of this file, and for a DISCLAIMER OF ALL WARRANTIES.
*
- * RCS: @(#) $Id: tclHash.c,v 1.15 2003/11/15 23:35:16 dkf Exp $
+ * RCS: @(#) $Id: tclHash.c,v 1.16 2003/12/24 04:18:19 davygrvy Exp $
*/
#include "tclInt.h"
@@ -193,7 +193,7 @@ Tcl_InitCustomHashTable(tablePtr, keyType, typePtr)
* the behaviour of this table. */
{
#if (TCL_SMALL_HASH_TABLE != 4)
- panic("Tcl_InitCustomHashTable: TCL_SMALL_HASH_TABLE is %d, not 4\n",
+ Tcl_Panic("Tcl_InitCustomHashTable: TCL_SMALL_HASH_TABLE is %d, not 4\n",
TCL_SMALL_HASH_TABLE);
#endif
@@ -548,7 +548,7 @@ Tcl_DeleteHashEntry(entryPtr)
} else {
for (prevPtr = *bucketPtr; ; prevPtr = prevPtr->nextPtr) {
if (prevPtr == NULL) {
- panic("malformed bucket chain in Tcl_DeleteHashEntry");
+ Tcl_Panic("malformed bucket chain in Tcl_DeleteHashEntry");
}
if (prevPtr->nextPtr == entryPtr) {
prevPtr->nextPtr = entryPtr->nextPtr;
@@ -1068,7 +1068,7 @@ HashStringKey(tablePtr, keyPtr)
* on a table that has been deleted.
*
* Results:
* If panic returns (which it shouldn't) this procedure returns
* NULL.
*
* Side effects:
@@ -1083,7 +1083,7 @@ BogusFind(tablePtr, key)
Tcl_HashTable *tablePtr; /* Table in which to lookup entry. */
CONST char *key; /* Key to use to find matching entry. */
{
- panic("called Tcl_FindHashEntry on deleted table");
+ Tcl_Panic("called Tcl_FindHashEntry on deleted table");
return NULL;
}
@@ -1114,7 +1114,7 @@ BogusCreate(tablePtr, key, newPtr)
int *newPtr; /* Store info here telling whether a new
* entry was created. */
{
- panic("called Tcl_CreateHashEntry on deleted table");
+ Tcl_Panic("called Tcl_CreateHashEntry on deleted table");
return NULL;
}
#endif
@@ -1068,7 +1068,7 @@ HashStringKey(tablePtr, keyPtr)
*
* Results:
- * If panic returns (which it shouldn't) this procedure returns
+ * If Tcl_Panic returns (which it shouldn't) this procedure returns
* NULL.
*